@@ -8,25 +8,25 @@ from python_framework.api.src.enumeration.HttpStatus import HttpStatus
 @Function
 def EncapsulateItWithGlobalException(message=DEFAULT_MESSAGE, status=HttpStatus.INTERNAL_SERVER_ERROR) :
     encapsulateItWithGlobalExceptionStatus = status
-    def wrapper(function,*args,**kwargs) :
-        log.wrapper(wrapper, f'Wrapping {function} function with (*{args} args and **{kwargs} kwargs)')
+    def wrapper(givenFunction,*args,**kwargs) :
+        log.wrapper(wrapper, f'Wrapping {givenFunction} function with (*{args} args and **{kwargs} kwargs)')
         def wrapedFunction(*args,**kwargs) :
             try :
-                functionReturn = function(*args,**kwargs)
+                givenFunctionReturn = givenFunction(*args,**kwargs)
             except Exception as exception :
                 if isinstance(exception, GlobalException):
                     raise exception
                 logMessage = str(exception) if StringHelper.isNotBlank(str(exception)) else LOG_MESSAGE_NOT_PRESENT
-                functionName = ReflectionHelper.getName(function, typeName=c.TYPE_FUNCTION)
-                log.wrapper(EncapsulateItWithGlobalException, f'''Failed to execute "{functionName}(args={args}, kwargs={kwargs})" {c.TYPE_FUNCTION} call''', exception)
+                givenFunctionName = ReflectionHelper.getName(givenFunction, typeName=c.TYPE_FUNCTION)
+                log.wrapper(EncapsulateItWithGlobalException, f'''Failed to execute "{givenFunctionName}(args={args}, kwargs={kwargs})" {c.TYPE_FUNCTION} call''', exception)
                 raise GlobalException(
                     message=message,
                     logMessage=logMessage,
-                    logResource=ReflectionHelper.getParentClass(function),
-                    logResourceMethod=function,
+                    logResource=ReflectionHelper.getParentClass(givenFunction),
+                    logResourceMethod=givenFunction,
                     status=HttpStatus.map(encapsulateItWithGlobalExceptionStatus).enumValue
                 )
-            return functionReturn
-        ReflectionHelper.overrideSignatures(wrapedFunction, function)
+            return givenFunctionReturn
+        ReflectionHelper.overrideSignatures(wrapedFunction, givenFunction)
         return wrapedFunction
     return wrapper
